@@ -7,10 +7,10 @@ use 5.10.0;
 
 my $bot = WWW::Crawler::Mojo->new;
 $bot->on(res => sub {
-    my ($bot, $discover, $job, $res) = @_;
+    my ($bot, $scrape, $job, $res) = @_;
     say sprintf('fetching %s resulted status %s',
                                     $job->resolved_uri, $res->code);
-    $discover->();
+    $scrape->();
 });
 $bot->on(refer => sub {
     my ($bot, $enqueue, $job, $context) = @_;
